#
# spec file for package python-Shed_Skin
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Shed_Skin
Version:        0.9.4
Release:        lp150.1.3
Url:            http://shedskin.googlecode.com
Summary:        An Optimizing (restricted) Python-to-C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/Python
Source:         http://shedskin.googlecode.com/files/shedskin-%{version}.tgz
Source1:        http://shedskin.googlecode.com/files/shedskin-examples-%{version}.tgz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#BuildRequires:  gc-devel
#BuildRequires:  gcc-c++
#BuildRequires:  pcre-devel
BuildRequires:  python-devel
Requires:       gc-devel
Requires:       gcc-c++
Requires:       pcre-devel
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Shed Skin is an experimental (restricted) Python-to-C++ compiler. It accepts
pure but implicitly statically typed Python programs and generates optimized
C++ code. The result can be further compiled to stand-alone programs or
extension modules. For a set of 57 non-trivial test programs, at more than
16,000 lines in total (sloccount), measurements show a typical speedup of
2-200 times compared to CPython. Not all Python features are supported, and
only a subset of about 20 library modules, such as re and random. See the
home page for more details.

%package doc
Summary:        An Optimizing (restricted) Python-to-C++ Compiler - Documentation
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
Shed Skin is an experimental (restricted) Python-to-C++ compiler. It accepts
pure but implicitly statically typed Python programs and generates optimized
C++ code. The result can be further compiled to stand-alone programs or
extension modules. For a set of 57 non-trivial test programs, at more than
16,000 lines in total (sloccount), measurements show a typical speedup of
2-200 times compared to CPython. Not all Python features are supported, and
only a subset of about 20 library modules, such as re and random. See the
home page for more details.

This package contains the documentation of %{name}.

%prep
%setup -q -n shedskin-%{version}
tar xxf %{SOURCE1} && mv shedskin-examples-%{version} examples # Unpack seperate examples
sed -i 's/\r$//' examples/{*.py,scene.txt,ml/*.{py,txt},testdata/*} # Fix wrong EOL encoding

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Disable testsuite, it takes far too long. Feel free to test after version updates:
#%%check
#python setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE README
%{_bindir}/shedskin
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc examples

%changelog
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 0.9.4
  + No changelog available
* Sun Apr 14 2013 p.drouand@gmail.com
- Update to version 0.9.3
- much improved support for arbitrary code at the class level
- support select.select (UNIX, danny milosavljevic)
- greatly optimized creating/extending arrays (triggered by piotr tarsa)
- new example programs (now 72 in total):
  - pygasus, a NES emulator (about 1500 lines, Maciek "Mistrall" Żuk)
  - timsort sorting algorithm (about 650 lines, dan stromberg)
  - a conflict-driven satisfiability solver (thomas leonard)
  - TarsaLZP, a data compression algorithm (about 900 lines, piotr tarsa)
  - minpng, a minimal uncompressed PNG encoder
- fix generator expression problem (triggered by piotr tarsa)
- improve string formatting and null chars (reported by jorik blaas)
- new -g option to disable GC warnings
- remaining fixes for GCC 4.7 (help from thomas spura, mos4567)
- avoid crash on non-existant attribute (reported by danny milosavljevic)
- improve include file ordering (triggered by danny)
- avoid trouble by adding main module to module cache (reported by badamomike)
- update random.expovariate to 2.7 behaviour, finally fixing test 172
- add a few warnings for broken python code
- fix for when module exists in multiple libdirs (shedskin -L)
- fix annotation crash (shedskin -a)
* Wed Mar 14 2012 saschpe@suse.de
- Update to version 0.9.1:
  - new -L option to add library directories (Artem Egorkine)
  - support /etc/shedskin/FLAGS, /usr/share/shedskin/lib (triggered by Paul Boddie)
  - support enumerate 'start' argument
  - itertools.product optimization (triggered by lesshaste)
  - str.join and str non-equality optimization (triggered by lesshaste)
  - new example: hq2x image scaling
  - fix for itertools.izip (Jérémie Roquet)
  - several fixes for MSVC (Liu Zhenhai)
  - fix os.listdir crash (Pierre-Marie de Rodat)
  - annotation fix (William Edwards)
  - fix for 'not a < b < c' (François Boutines)
  - os.popen2 improvement (triggered by Danny Milosavljevic)
  - improved extmod warnings (triggered by Paul Boddie)
  - sys.exit improvements (reported by rodseth)
  - added missing class qualifier/include statement
  - fix for ConfigParser model (reported by Danny Milosavljevic)
- Changes from version 0.9.0:
  - major type inference scalability improvements (c64 emulator 10 times faster!)
  - support for 'mmap' module (francois boutines)
  - support for 'binascii' module (fahrzin hemmati)
  - support for 'colorsys' module (tony veijalainen)
  - greatly improved file I/O performance (francois)
  - massive optimization for complex numbers (copy-by-value)
  - optimized 'for .., .. in somedict.iteritems()'
  - 6 new example programs (now 63 in total!):
  - natural language parser (andreas van cranenburgh)
  - sokoban (uses array, collections.deque)
  - connect-4
  - interactive mandelbrot (tony veijalainen)
  - dancing links sudoku solver
  - K-means++ clustering
  - c64 emulator example now without glitches for international karate
  - fixes for 'universal mode' (francois)
  - only print tracebacks for uncaught exceptions (shedskin -x; joris van zwieten)
  - some further exception handling cleanups
  - add set.isdisjoint, sys.maxsize (brent pedersen)
  - several set methods now take multiple arguments (brent)
  - string equality optimization (francois)
  - fix for string/array equality and \0 (francois)
  - improved support for overloading comparison operators
  - several inheritance fixes (thanks to test case by jason ye)
  - improvements for working with 'incompatible' types (e.g., [[]] == [[1]])
  - implementation of builtins split up into separate files (triggered by francois)
  - cleaned up GCC warnings for builtins (triggered by francois)
  - support 'id' builtin for non-scalars
  - some optimizations for array('c')
  - some improvements for 'copy' module
  - use 'long' type for hash values everywhere
  - support for 'isinstance' was dropped
  - avoid 'jump' to 100%% in progress bar
  - removed -d command-line option, replaced it with hidden debug-level option
  - add --silent mode, showing only warnings
  - add timer (jason ye)
  - os.utime implementation for windows
  - documented how to profile extension modules
  - documentation moved to wiki
- Use examples from external tarball
- Remove outdated %%clean section
- Simplified macro usage
- Added some requirements you typically want to have when translating
  Python modules to C++ with Shed Skin
* Wed Aug  3 2011 cfarrell@novell.com
- license update: GPL-3.0+
  has an or later clause
* Fri Jul  1 2011 saschpe@suse.de
- Initial version
